# Galactic source with dec minus 413 and NSB tuning

## 20220523

## Short description of the config

Config for a galactic source with dec min_413 and NSB tuning:

"image_modifier": {
        "increase_nsb": true,
        "extra_noise_in_dim_pixels": 0.937
        "extra_bias_in_dim_pixels": 0.323
        "transition_charge": 8,
        "extra_noise_in_bright_pixels": 1.041
    }


## Why this config is needed

Processing of data taken from this galactic source which has a particular NSB level